# What's Changed

> 由于重写了会话记录部分，更新此版本后，将会造成之前的对话记录清空（但没有被删除）。
> 关于更好的对话管理，如果有任何报错或者优化建议，请直接提交 issue~

1. 修复 reminder 时区问题
2. 面板支持重载单个插件 #297
3. 面板支持列表展示插件市场
4. 文字转图片支持自定义字数阈值(配置->其他配置)
5. 面板更好的列表可视化 #274
6. 面板支持查看插件行为
7. 支持设置 timeout 超时时间参数，防止思考模型太长达到超时时间。(需要重新配置服务提供商或者在服务提供商 config 中配置 timeout 参数) #378
8. openrouter 报错 no endpoints found that support tool use #371
9. 修复插件 metadata 不生效的问题
10. 修复不支持图片的模型请求异常
11. 修复 reminder 无法删除的问题 
12. 修复 /model 切换不了模型的问题
13. 插件支持设置优先级 
14. 聊天增强图像转述支持自定义 provider id。#274
